*--------------------------------------------------------------------------
* Model generated by Motega software: 
*
*              Modeling Of Tubes Employing Genetic Algorithms
*
* Models contain 1G resistors from all nodes to earth in order to avoid
* floating nodes. Triode and tetrode/pentode models contain a diode for
* simulating grid current.
*
* Non-commercial use is permitted, but at your own risk... This model
* is provided "as is", without warranty of any kind. In no event shall
* Jeroen Boschma be liable for any claim, damages or other liability,
* whether in an action of contract, tort or otherwise, arising from,
* out of or in connection with the tube model or the use or other
* dealings in the tube model.
*
*
*                         Copyright Jeroen Boschma
*                              www.boschma.com
*
* Motega V 1.0, 12-Sep-2010 23:58:18
*--------------------------------------------------------------------------



*--------------------------------------------------------------------------
* Generic tetrode/pentode model
*--------------------------------------------------------------------------

.SUBCKT TubePentode  A  Gr2  Gr1  K
+ PARAMS: ua=1 ug2=1 xa=1 xg2=1 qa=1 qg2=1 kg1=1 kg2=1 kvba=1 kvbg2=1 ce=1
*
* Resistors in order to avoid floating nodes
*
R1   A    0   1G
R2   Gr2  0   1G
R3   Gr1  0   1G
R4   K    0   1G
*
* Intermediate expressions which simplify the current calculation
*
RE1  1    0   1G
E1   1    0   VALUE={xa + ce*PWR(V(A,K),2)}
RE2  2    0   1G
E2   2    0   VALUE={V(Gr2,K)*LOG(1 + EXP(qa*(1/ua + V(Gr1,K)/V(Gr2,K))))/qa}
RE3  3    0   1G
E3   3    0   VALUE={V(Gr2,K)*LOG(1 + EXP(qg2*(1/ug2 + V(Gr1,K)/V(Gr2,K))))/qg2}
*
* Actual current calculation
*
G1   A    K   VALUE={(PWR(V(2),V(1)) + PWRS(V(2),V(1)))*ATAN(V(A,K)/kvba)/kg1}
G2   Gr2  K   VALUE={(PWR(V(3),V(1)) + PWRS(V(3),V(1)))*ATAN(V(A,K)/kvbg2)/kg2}
*
* Grid current modeling
*
RG   Gr1  4   1K
D1   4    K   DX
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N)
*
* Close the model
*
.ENDS


*--------------------------------------------------------------------------
* Specialized tube model
*
*    Type           : 6F12P
*    Description    : Pentode only
*    Direct heated  : no
*    Screen present : no
*--------------------------------------------------------------------------

.SUBCKT 6F12PP    A  Gr2  Gr1  K 
*
* Resistors in order to avoid floating nodes
*
* RF   F    0   1G
*
* Link to the generic model
*
XV1     A         Gr2      Gr1      K       TubePentode
+ PARAMS: ua=164.060 ug2=2.189K xa=442.879M xg2=687.751M qa=620.235 qg2=93.692
+ kg1=89.910 kg2=161.636 kvba=11.369 kvbg2=655.832 ce=358.645N
*
* Capacitances
*
C1    K        Gr1      6.600P   ; Ckg1
C2    K        A        1.900P   ; Cka
C3    Gr1      A        0.020P   ; Cg1a
*
* Close the model
*
.ENDS


*--------------------------------------------------------------------------
* End of file
*--------------------------------------------------------------------------